@@ -25,6 +25,10 @@ class PresidioPy():
     def recognizers_url(self):
         return self.base_url + 'analyzer/recognizers/'
 
+    @property
+    def anonymize_url(self):
+        return self.base_url + 'projects/' + self.project + '/anonymize'
+
     @property
     def field_types_url(self):
         return self.base_url + 'fieldTypes'
@@ -32,6 +36,13 @@ class PresidioPy():
     def change_project(self, project):
         self.project = project
 
+    def add_field_type(self, field, **kwargs):
+        name = field['value']['entity']
+        return self.request('post', self.recognizers_url + name, json=field, **kwargs)
+
+    def delete_field_type(self, recognizer_name):
+        return self.request('delete', self.recognizers_url + recognizer_name)
+
     def analyze(self, text, **kwargs):
         data = {
             'text': text
@@ -47,9 +58,26 @@ class PresidioPy():
 
         return self.request('post', self.analyze_url, json=data)
 
-    def retrieve_field_types(self):
-        url = self.field_types_url
-        return self.request('get', url)
+    def anonymization(self, text, **kwargs):
+        data = {
+            "text": text
+        }
+
+        if kwargs.get("analyzeTemplate"):
+            data["AnalyzeTemplate"] = kwargs.get("analyzeTemplate")
+        elif kwargs.get("analyzeTemplateId"):
+            data["AnalyzeTemplateId"] = kwargs.get("analyzeTemplateId")
+        else:
+            data["AnalyzeTemplate"] = {"allFields": True}
+
+        if kwargs.get("anonymizeTemplate"):
+            data["AnonymizeTemplate"] = kwargs.get("anonymizeTemplate")
+        elif kwargs.get("anonymizeTemplateId"):
+            data["AnonymizeTemplateId"] = kwargs.get("anonymizeTemplateId")
+        else:
+            raise Exception("missing AnonymizeTemplate or AnonymizeTemplateId")
+
+        return self.request('post', self.anonymize_url, json=data)
 
     def retrieve_recognizers(self, *args):
         url = self.recognizers_url
@@ -57,14 +85,9 @@ class PresidioPy():
             url += str(args[0])
         return self.request('get', url)
 
-    def add_recognizer_type(self, recognizer, recognizer_data, **kwargs):
-        return self.request('post', self.recognizers_url + recognizer, json=recognizer_data, **kwargs)
-
-    def delete_recognizer_type(self, recognizer):
-        return self.request('delete', self.recognizers_url + recognizer)
-
-    def retrieve_recognizer_type(self, recognizer):
-        return self.request('get', self.recognizers_url + recognizer)
+    def retrieve_field_types(self):
+        url = self.field_types_url
+        return self.request('get', url)
 
     def request(self, method, url, **kwargs):
         if method == 'get':
